@@ -237,7 +237,7 @@ class Dependencies:
     # config must be passed in explicitly.
     config: Config
     settings: Settings
-    search_cache: ThreadSafeCache[str, list] = dataclasses.field(default_factory=ThreadSafeCache)
+    search_cache: ThreadSafeCache[Flags, list] = dataclasses.field(default_factory=ThreadSafeCache)
 
     @cached_property
     def openai_client(self) -> "OpenAI":
@@ -348,7 +348,7 @@ def index_paths(
                     try:
                         if entry.is_symlink():
                             continue
-                        if entry.is_dir():
+                        if entry.is_dir() and not entry.name.startswith('.'):
                             events.append(Events.Directory(entry_path))
                         elif entry.is_file():
                             events.append(Events.File(entry_path))
@@ -541,7 +541,9 @@ def index_paths(
                 lines = file_bytes.split(b'\n')
                 requests_to_schedule = []
                 for obj_id, obj in objects_by_id.items():
-                    rendered = render_object(obj, in_lines=lines)
+                    rendered = render_object(obj, in_lines=lines, file=False)
+                    if not rendered:
+                        continue
                     request = EmbeddingRequest(
                         object_id=obj_id,
                         content=rendered,
@@ -668,7 +670,7 @@ def index_paths(
         raise
 
 
-@dataclasses.dataclass
+@dataclasses.dataclass(frozen=True)
 class Flags:
     directory: Path
     background: bool
@@ -680,3 +682,4 @@ class Flags:
     full_text_search: bool
     top_k: int
     query: str
+    rerank: bool
